| Title: | Gene Annotation of Rice (Oryza Sativa L.spp.japonica) |
|---|---|
| Description: | Gene annotation of rice (Oryza Sativa L.spp.japonica). The package is based on the annotation file from the website <http://plants.ensembl.org/Oryza_sativa/Info/Index>. Input gene's name then return some information, including the from position, the end position, the position type and the chromosome number. |
| Authors: | Xiang LI, Linna MA |
| Maintainer: | Xiang LI <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.0.2 |
| Built: | 2026-06-04 10:55:52 UTC |
| Source: | https://github.com/cran/ricegeneann |
ricegeneann Annotate the gene of rice (Oryza Sativa)
ricegeneannotation(myID, type)ricegeneannotation(myID, type)
myID |
A vector of entrez id |
type |
Keytype of input id |
Return a vector or a datafram
Xiang LI <[email protected]> Linna MA <[email protected]>
convert_id <- ricegeneannotation('Os01g0100500','RAP') convert_id <- ricegeneannotation(myID = 'Os01g0100500', type = 'RAP')convert_id <- ricegeneannotation('Os01g0100500','RAP') convert_id <- ricegeneannotation(myID = 'Os01g0100500', type = 'RAP')
ricegeneann Annotation of genes of rice (Oryza Sativa).
Input a or some gene name then return a or some information,
including the from position, end position, position type and
the chromosome number.
Xiang LI <[email protected]> Linna MA <[email protected]>